==> Business-CyberSource-0.007009.tar.gz: Business-CyberSource-0.007009/lib/Business/CyberSource/ResponsePart/PurchaseTotals.pm <==
package Business::CyberSource::ResponsePart::PurchaseTotals;
use strict;
use warnings;
use namespace::autoclean;

our $VERSION = '0.007009'; # VERSION

use Moose;
extends 'Business::CyberSource::MessagePart';
with qw(
	Business::CyberSource::Role::Currency
	Business::CyberSource::Role::ForeignCurrency
);

__PACKAGE__->meta->make_immutable;
1;
# ABSTRACT: PurchaseTotals part of response

__END__

=pod

=head1 NAME

Business::CyberSource::ResponsePart::PurchaseTotals - PurchaseTotals part of response

=head1 VERSION

version 0.007009

=head1 EXTENDS

L<Business::CyberSource::MessagePart>

=head1 WITH

=over

=item L<Business::CyberSource::Role::Currency>

=item L<Business::CyberSource::Role::ForeignCurrency>

=back

=head1 ATTRIBUTES

=head2 currency

=head2 foreign_currency

Billing currency returned by the DCC service. For the possible values, see the ISO currency codes

=head2 foreign_amount

=head2 exchange_rate

=head2 exchange_rate_timestamp

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
https://github.com/hostgator/business-cybersource/issues or by email to
development@hostgator.com.

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Caleb Cushing <xenoterracide@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2012 by L<HostGator.com|http://hostgator.com>.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut

==> Business-CyberSource-0.007011.tar.gz: Business-CyberSource-0.007011/lib/Business/CyberSource/ResponsePart/PurchaseTotals.pm <==
package Business::CyberSource::ResponsePart::PurchaseTotals;
use strict;
use warnings;
use namespace::autoclean;

our $VERSION = '0.007011'; # VERSION

use Moose;
extends 'Business::CyberSource::MessagePart';
with qw(
	Business::CyberSource::Role::Currency
	Business::CyberSource::Role::ForeignCurrency
);

__PACKAGE__->meta->make_immutable;
1;
# ABSTRACT: PurchaseTotals part of response

__END__

=pod

=head1 NAME

Business::CyberSource::ResponsePart::PurchaseTotals - PurchaseTotals part of response

=head1 VERSION

version 0.007011

=head1 EXTENDS

L<Business::CyberSource::MessagePart>

=head1 WITH

=over

=item L<Business::CyberSource::Role::Currency>

=item L<Business::CyberSource::Role::ForeignCurrency>

=back

=head1 ATTRIBUTES

=head2 currency

=head2 foreign_currency

Billing currency returned by the DCC service. For the possible values, see the ISO currency codes

=head2 foreign_amount

=head2 exchange_rate

=head2 exchange_rate_timestamp

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
https://github.com/xenoterracide/business-cybersource/issues

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Caleb Cushing <xenoterracide@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2013 by L<HostGator.com|http://hostgator.com>.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut
